Calculate Daily Activity Measures
calculate_daily_activity_measures(
MPI,
daily_bouts,
minimum_valid_hours = 22,
include_participant_info = FALSE
)Activity measures data frame for all days
Measurement Period Information.
Function used to read daily bouts or extract them from the aggregated bouts file
Minimum hours of wear time in a 24-hour day to be considered a valid day for reported measures.
If TRUE, appends participant information extracted from the bin file to both the activity and sleep measures.
Function that calculates the daily activity measures only