Learn R Programming

GENEAcore (version 1.2.0)

create_summary: Create Summary

Description

Create Summary

Usage

create_summary(
  input,
  path_type,
  recursive = TRUE,
  identifier_mapping_record = NULL
)

Value

Data frame of bin file or MPI summary.

Arguments

input

Input type of either a bin file path, MPI path or an MPI object.

path_type

The file type within the folder to create summary for.

recursive

TRUE applies the operation to all nested elements.

identifier_mapping_record

File path of the exported identifier_mapping_record CSV file.

Details

Function to create a summary of key information of a bin file or MPI path.