Learn R Programming

GENEAcore (version 1.2.0)

cx_percentile: Compute Cx percentile

Description

Compute Cx percentile

Usage

cx_percentile(
  bouts,
  percentile = 95,
  value_col = "StepMean",
  duration_col = "Duration"
)

Value

A single numeric value or NA if percentile cannot be calculated

Arguments

bouts

A data frame sorted by time containing at minimum a value_col and duration_col.

percentile

The percentile to compute. Single integer between 0 and 100. Default is 95.

value_col

The column name of the variable for which the percentile will be calculated (e.g., "StepMean).

duration_col

The column name of the duration or weight column (e.g., "Duration").

Details

Calculates the xth percentile of cadence for a given percentile.