Learn R Programming

GENEAcore (version 1.2.0)

detect_transitions: Detect Transitions

Description

Detect Transitions

Usage

detect_transitions(
  measurements,
  minimum_event_duration = 5,
  x_cpt_penalty = 18,
  y_cpt_penalty = 25,
  z_cpt_penalty = 16,
  cut_time_24hr = "15:00"
)

Value

List of time and index of each transition.

Arguments

measurements

The downsampled measurements to calculate changepoint transitions.

minimum_event_duration

The minimum interval between changepoint transitions.

x_cpt_penalty

The manual penalty value applied in the PELT changepoint algorithm for the x axis, see cpt.var.

y_cpt_penalty

The manual penalty value applied in the PELT changepoint algorithm for the y axis, see cpt.var.

z_cpt_penalty

The manual penalty value applied in the PELT changepoint algorithm for the z axis, see cpt.var.

cut_time_24hr

Time in 24h to split days up by.

Details

Function to detect mean and variance changepoints in 1Hz acceleration data from a bin file.