Learn R Programming

GENEAcore (version 1.2.0)

expected_last_timestamp: Calculate Expected Last Timestamp

Description

Calculate Expected Last Timestamp

Usage

expected_last_timestamp(measurement_frequency, page_count, first_timestamp)

Value

Expected last timestamp

Arguments

measurement_frequency

Measurement frequency of recorded data in the bin file.

page_count

Total number of pages in the bin file.

first_timestamp

Unix timestamp of the first page of recorded data in the bin file.

Details

Calculates the expected last timestamp of a file based on measurement frequency, page count and first timestamp of file.