Learn R Programming

GENEAcore (version 1.2.0)

find_rest_intervals: Determine Daily Recommended Primary Rest Interval

Description

Determine Daily Recommended Primary Rest Interval

Usage

find_rest_intervals(
  start_expansion_percent,
  end_expansion_percent,
  cut_time_24hr,
  MPI
)

Arguments

start_expansion_percent

The percentage expansion, based on duration, of a still period's start time to identify overlaps with near-adjacent still periods.

end_expansion_percent

The percentage expansion, based on duration, of a still period's end time to identify overlaps with near-adjacent still periods.

cut_time_24hr

Time in 24h to split days up by.

MPI

Measurement Period Information.

Details

Twice the expansion before than after.