Learn R Programming

GENEAcore (version 1.2.0)

folder_measures: Daily Measures for Data Folder

Description

Daily Measures for Data Folder

Usage

folder_measures(
  data_folder,
  measure_type = c("activity", "sleep", "both"),
  minimum_valid_hours = 22,
  include_participant_info = FALSE,
  identifier_mapping_record = NULL
)

Value

Daily aggregated activity measures (.csv)

Arguments

data_folder

Folder that contains raw data bin files to process or path to single bin file.

measure_type

The type of daily measure summary to generate.

minimum_valid_hours

Minimum hours of wear time in a 24-hour day to be considered a valid day for reported measures.

include_participant_info

If TRUE, appends participant information extracted from the bin file to both the activity and sleep measures.

identifier_mapping_record

File path of the exported identifier_mapping_record CSV file.

Details

Wrapper to process and output daily activity measures aggregate for all bin files in the data folder