Learn R Programming

GENEAcore (version 1.2.0)

fx_count: Compute Fx metrics

Description

Compute Fx metrics

Usage

fx_count(bouts, AGSA_threshold = 0.0625, duration = 3600)

Value

A list containing the maximum and minimum bout counts and their corresponding start times for the supplied bouts data at a given window.

Arguments

bouts

A bouts data frame sorted by time containing at minimum the TimeUTC and AGSAMean columns.

AGSA_threshold

Threshold for active classification in g. Default is 0.0625 (62.5mg).

duration

Duration of active time in seconds. Default is 3600 seconds (60 minutes).

Details

Calculates frequency of bouts for each x duration window.