GENEAbout function which performs the following tasks for each available day:
Assign bout classifications to events only
Reports aggregated daily activity and sleep measures
Creates COEL v2.0 Behavioural Atoms JSON
Usage
geneabout(data_folder = data_folder, control = list())
Arguments
data_folder
Folder that contains raw data bin files to process or path to single bin file.
control
Named list of optional settings for geneacore functions.
Details
Control options (all optional):
timer
Logical. Default FALSE. Print elapsed times of each processing step.
minimum_valid_hours
Integer. Default 22.
Minimum hours of wear time in a 24-hour day to be considered a valid day for reported measures.
save_daily_bouts
Logical. Default FALSE.
If TRUE,daily bouts are saved as RDS files and CSV files (if output_csv is set to TRUE).
If FALSE, only a single RDS file containing bouts for all processed days is saved.
coel_json
Logical. Default FALSE. Exports bouts as COEL behavioural atoms in JSON format.
For each bin file in the data folder, behavioural bout atoms and rest activity atoms are produced.
Additionally, aggregated JSON files are created in the Batch JSON outputs subfolder.
identifier_mapping_record
String. Default NULL.
If a file path to the exported identifier_mapping_record.csv is provided,
encrypted participant IDs in the activity and sleep measures will be replaced
with their corresponding mapped identifiers.