Learn R Programming

GENEAcore (version 1.2.0)

geneacore_part1: GENEAcore Part 1

Description

GENEAcore function which performs the following tasks:

  • Checks and reads the data file and creates the Measurement Period Information (MPI)

  • Downsamples the file to 1Hz and detects periods of non movement

  • Calculates auto calibration parameters for the device

Usage

geneacore_part1(data_folder = data_folder, control = list())

Value

Measurement Period Information (.rds, .json) and 1Hz downsampled data (.rds)

Arguments

data_folder

Folder that contains raw data bin files to process or path to single bin file.

control

Named list of optional settings for geneacore functions.

Details

Control options (all optional):

cut_time_24hr

String. Default "15:00". Time in 24h to split days up by.

timer

Logical. Default FALSE. Print elapsed times of each processing step.

Examples

Run this code
if (FALSE) {
controls <- list(output_csv = TRUE, required_processing_hours = 4, timer = TRUE)
geneacore_part1("path/to/folder", controls)
}

Run the code above in your browser using DataLab