Learn R Programming

GENEAcore (version 1.2.0)

geneacore_part4: GENEAcore Part 4

Description

GENEAcore function which performs the following tasks:

  • Consolidates daily epochs or bouts outputs into a single file

Usage

geneacore_part4(data_folder = data_folder, control = list())

Value

Consolidated epochs and/or bouts output (.rds/.csv)

Arguments

data_folder

Folder that contains raw data bin files to process or path to single bin file.

control

Named list of optional settings for geneacore functions.

Details

Control options (all optional):

output_epochs

Logical. Default TRUE. Create epoch outputs.

epoch_duration

Integer. Default 1. Specify duration of fixed epochs.

output_events

Logical. Default TRUE. Create event outputs.

output_csv

Logical. Default FALSE. Allows CSV output to be saved during epoch and event processing.

Examples

Run this code
if (FALSE) {
controls <- list(output_csv = TRUE, minimum_valid_hours = 4, timer = TRUE)
geneacore_part4("path/to/folder", controls)
}

Run the code above in your browser using DataLab