Learn R Programming

GENEAcore (version 1.2.0)

mx_lx_window: Compute Mx and Lx metrics

Description

Compute Mx and Lx metrics

Usage

mx_lx_window(bouts, window, low = TRUE)

Value

A list containing the maximum and minimum mean intensity and their corresponding start times for the supplied bouts data at a given window.

Arguments

bouts

A data frame sorted by time containing at minimum the columns TimeUTC, Duration and AGSAMean.

window

Window length in seconds.

low

Set to TRUE for both the maximum (Mx) and minimum (Lx) intensities are returned. If FALSE, only the maximum (Mx) is returned.

Details

Calculates intensity for each x duration window.