Learn R Programming

GENEAcore (version 1.2.0)

nonwear_rest_coverage: Non-wear and Rest Coverage for Epochs/Events

Description

Non-wear and Rest Coverage for Epochs/Events

Usage

nonwear_rest_coverage(
  MPI,
  aggregated_data,
  start_time = NULL,
  end_time = NULL,
  nonwear_day
)

Arguments

MPI

Measurement Period Information.

aggregated_data

Aggregated epochs or events.

start_time

Time stamp to start the coverage assignment, defaults to first time stamp of aggregated data object passed.

end_time

Time stamp to end the coverage assignment, defaults to end time stamp of aggregated data object passed.

nonwear_day

Data frame of non-wear periods and their durations.