Daily Measures for Single Bin File
single_file_measures(
output_folder,
UniqueBinFileIdentifier,
measure_type = c("activity", "sleep", "both"),
minimum_valid_hours = 22,
include_participant_info = FALSE,
identifier_mapping_record = NULL
)Daily aggregated activity measures (.csv)
Path to the folder containing GENEAcore run outputs and Measurement Period Information (MPI) files.
The Unique Bin File Identifier of a bin file.
The type of daily measure summary to generate.
Minimum hours of wear time in a 24-hour day to be considered a valid day for reported measures.
If TRUE, appends participant information extracted from the bin file to both the activity and sleep measures.
File path of the exported identifier_mapping_record CSV file.
Wrapper to process and output daily activity measures aggregate for a single bin file