Learn R Programming

GENEAcore (version 1.2.0)

valid_day_nonwear: Determine Valid Days

Description

Determine Valid Days

Usage

valid_day_nonwear(
  MPI_nonwear,
  date_range,
  required_processing_hours = 0,
  cut_time_24hr = "15:00"
)

Value

List of 2 data objects:

  • valid_day provides information on the wear and non-wear duration for each day and its Boolean validity based on minimum_valid_day.

  • nonwear_day provides the start and end time of each non-wear period and the day in which it occurs.

Arguments

MPI_nonwear

MPI non-wear data frame with start times and durations of non-wear events.

date_range

Data frame of day border timestamps.

required_processing_hours

Hours of wear time in a 24-hour day to be considered a valid day to be processed.

cut_time_24hr

Time in 24h to split days up by.

Details

Determine which days of data are valid days to process based on non-wear calculated in MPI and a minimum valid day duration.