create_coel_atoms_json: Create COEL Behavioural Atoms JSON
Description
Creates per-participant rest activity and behavioural bout atoms and a payload
Usage
create_coel_atoms_json(data_folder)
Arguments
- data_folder
Folder that contains raw data bin files for which bouts have been created for.