Create Summary
create_summary(
input,
path_type,
recursive = TRUE,
identifier_mapping_record = NULL
)Data frame of bin file or MPI summary.
Input type of either a bin file path, MPI path or an MPI object.
The file type within the folder to create summary for.
TRUE applies the operation to all nested elements.
File path of the exported identifier_mapping_record CSV file.
Function to create a summary of key information of a bin file or MPI path.