Compute Cx percentile
cx_percentile(
bouts,
percentile = 95,
value_col = "StepMean",
duration_col = "Duration"
)A single numeric value or NA if percentile cannot be calculated
A data frame sorted by time containing at minimum a value_col and duration_col.
The percentile to compute. Single integer between 0 and 100. Default is 95.
The column name of the variable for which the percentile will be calculated (e.g., "StepMean).
The column name of the duration or weight column (e.g., "Duration").
Calculates the xth percentile of cadence for a given percentile.