Calculate Expected Last Timestamp
expected_last_timestamp(measurement_frequency, page_count, first_timestamp)Expected last timestamp
Measurement frequency of recorded data in the bin file.
Total number of pages in the bin file.
Unix timestamp of the first page of recorded data in the bin file.
Calculates the expected last timestamp of a file based on measurement frequency, page count and first timestamp of file.