Daily Measures for Data Folder
folder_measures(
data_folder,
measure_type = c("activity", "sleep", "both"),
minimum_valid_hours = 22,
include_participant_info = FALSE,
identifier_mapping_record = NULL
)Daily aggregated activity measures (.csv)
Folder that contains raw data bin files to process or path to single bin file.
The type of daily measure summary to generate.
Minimum hours of wear time in a 24-hour day to be considered a valid day for reported measures.
If TRUE, appends participant information extracted from the bin file to both the activity and sleep measures.
File path of the exported identifier_mapping_record CSV file.
Wrapper to process and output daily activity measures aggregate for all bin files in the data folder