GENEAcore function that wraps the functionalities of geneacore_part1 to geneacore_part4. GENEAcore function which performs the following tasks for each valid day:
Checks and reads the data file and creates the Measurement Period Information (MPI)
Downsamples the file to 1Hz and detects periods of non movement
Calculates auto calibration parameters for the device
Samples daily raw bin file data and saves as daily RDS files
Reads and saves button press timestamps to the Measurement Period Information (MPI)
Applies calibration parameters to raw data
Identifies transitions for events processing only
Performs aggregation by event and/or epoch
Calculate steps, if option selected
Calculate non-wear coverage and rest coverage of events and/or epochs
Assign bout classifications to events only
Reports aggregated daily activity and sleep measures
Consolidates daily epochs or bouts outputs into a single file
geneacore(data_folder = data_folder, control = list())Folder that contains raw data bin files to process or path to single bin file.
Named list of optional settings for geneacore functions.
Control options (all optional):
String. Default "15:00". Time in 24h to split days up by.
Logical. Default FALSE. Create epoch outputs.
Integer. Default 1. Specify duration of fixed epochs.
Logical. Default TRUE. Create event outputs.
Logical. Default FALSE. Calculate step counts and stepping rate during epoch processing.
Steps are always calculated during events processing.
Logical. Default FALSE. Allows CSV output to be saved during epoch and event processing.
Logical. Default FALSE. Print elapsed times of each processing step.
Integer vector of length 2. Default c(1,1).
Controls day split when running function across multiple R sessions.
The first value is the current session number and the second is the total number of sessions.
The default processes all days in a single session.
Integer. Default 0. Hours of wear time in a 24-hour day to be considered a valid day to be processed.
if (FALSE) {
controls <- list(output_csv = TRUE, required_processing_hours = 4, timer = TRUE)
geneacore("path/to/folder", controls)
}
Run the code above in your browser using DataLab