Learn R Programming

GENEAcore (version 1.1.2)

geneacore: Main GENEAcore Function

Description

Main GENEAcore Function which performs the following tasks:

  • Checks for and reads or creates Measurement Processing Information (MPI)

  • Downsamples the file to 1Hz and detects periods of non movement

  • Calculates auto calibration settings for the device

  • Identifies transitions (if processing events)

  • Applies auto calibration scaling

  • Counts steps

  • Performs aggregations by event or epoch

  • Writes out data

Usage

geneacore(
  data_folder = data_folder,
  cut_time_24hr = "15:00",
  output_epochs = TRUE,
  epoch_duration = 1,
  output_events = TRUE,
  output_steps = FALSE,
  output_csv = FALSE,
  timer = FALSE,
  summary = FALSE
)

Value

RDS and CSV of Measurement Period Information, Epoch measures and Event measures.

Arguments

data_folder

Folder that contains raw data bin files to process or path to single bin file.

cut_time_24hr

Time in 24h to split the days up by.

output_epochs

Create epoch outputs.

epoch_duration

Specify duration of fixed epochs.

output_events

Create event outputs.

output_steps

Include step counts and stepping rate outputs.

output_csv

Allows CSV output to be saved during epoch and event processing.

timer

Print elapsed times of each process.

summary

Create bin file summary for all files in data folder.