powered by
GENEAcore function which performs the following tasks for each valid day:
Samples daily raw bin file data and saves as daily RDS files
Reads and saves button press timestamps to the Measurement Period Information (MPI)
geneacore_part2(data_folder = data_folder, control = list())
Daily raw data sample of x, y, z, Light, Button, Temperature and Voltage (.rds)
Folder that contains raw data bin files to process or path to single bin file.
Named list of optional settings for geneacore functions.
Control options (all optional):
Integer. Default 0. Hours of wear time in a 24-hour day to be considered a valid day to be processed.
Logical. Default FALSE. Print elapsed times of each processing step.
FALSE
if (FALSE) { controls <- list(output_csv = TRUE, required_processing_hours = 4, timer = TRUE) geneacore_part2("path/to/folder", controls) }
Run the code above in your browser using DataLab