powered by
GENEAcore function which performs the following tasks:
Consolidates daily epochs or bouts outputs into a single file
geneacore_part4(data_folder = data_folder, control = list())
Consolidated epochs and/or bouts output (.rds/.csv)
Folder that contains raw data bin files to process or path to single bin file.
Named list of optional settings for geneacore functions.
Control options (all optional):
Logical. Default TRUE. Create epoch outputs.
TRUE
Integer. Default 1. Specify duration of fixed epochs.
Logical. Default TRUE. Create event outputs.
Logical. Default FALSE. Allows CSV output to be saved during epoch and event processing.
FALSE
if (FALSE) { controls <- list(output_csv = TRUE, minimum_valid_hours = 4, timer = TRUE) geneacore_part4("path/to/folder", controls) }
Run the code above in your browser using DataLab