Compute Mx and Lx metrics
mx_lx_window(bouts, window, low = TRUE)A list containing the maximum and minimum mean intensity and their corresponding start times for the supplied bouts data at a given window.
A data frame sorted by time containing at minimum the columns TimeUTC, Duration and AGSAMean.
Window length in seconds.
Set to TRUE for both the maximum (Mx) and minimum (Lx) intensities are returned. If FALSE, only the maximum (Mx) is returned.
Calculates intensity for each x duration window.