Non-wear and Rest Coverage for Epochs/Events
nonwear_rest_coverage(
MPI,
aggregated_data,
start_time = NULL,
end_time = NULL,
nonwear_day
)Measurement Period Information.
Aggregated epochs or events.
Time stamp to start the coverage assignment, defaults to first time stamp of aggregated data object passed.
Time stamp to end the coverage assignment, defaults to end time stamp of aggregated data object passed.
Data frame of non-wear periods and their durations.